
#line 3 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 31
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined __STDC_VERSION__ && __STDC_VERSION__ >= 199901L
#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 1;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 107
#define YY_END_OF_BUFFER 108
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[565] =
    {   0,
        0,    0,  108,  103,   98,   99,   90,  104,  101,   87,
       91,   88,   89,   94,  105,  103,  103,  103,  103,  103,
      103,  103,  103,  103,  103,  103,  103,  103,  103,  103,
      103,  103,  103,  103,  103,  103,  103,   92,  103,   98,
       99,  101,    0,    0,  102,    0,  101,  101,  100,   96,
       94,    0,   97,  103,  103,  103,  103,   19,  103,  103,
      103,  103,  103,  103,  103,  103,  103,  103,   37,  103,
      103,  103,  103,   32,  103,  103,  103,  103,  103,  103,
      103,  103,  103,  103,  103,  103,  103,  103,  103,  103,
      103,  103,  103,  103,  103,  103,  103,  103,  103,  103,

        0,    0,    0,   95,   94,   97,  103,  103,  103,  103,
      103,  103,  103,  103,  103,  103,  103,  103,  103,  103,
      103,   31,   63,  103,  103,  103,  103,  103,  103,  103,
      103,  103,  103,   71,  103,  103,  103,  103,  103,  103,
      103,  103,  103,  103,  103,  103,  103,  103,  103,  103,
      103,  103,  103,  103,  103,  103,  103,  103,  103,  103,
      103,  103,    0,    0,   95,   94,  103,  103,  103,   67,
      103,  103,   64,   68,  103,  103,  103,   35,   36,  103,
      103,  103,  103,   40,   42,  103,   51,  103,  103,   60,
       70,  103,   72,  103,   73,  103,  103,  103,  103,  103,

      103,  103,   30,  103,   85,  103,  103,  103,  103,  103,
      103,  103,  103,  103,  103,  103,   75,   76,  103,   62,
      103,    0,   95,   94,  103,   65,  103,  103,  103,  103,
      103,   59,  103,   66,  103,   93,  103,   38,  103,  103,
      103,  103,  103,  103,  103,  103,  103,  103,  103,  103,
       41,  103,  103,   49,  103,  103,  103,  103,  103,  103,
      103,  103,  103,  103,  103,   86,   95,   94,  103,  103,
      103,  103,  103,   69,  103,  103,  103,  103,  103,  103,
       70,   77,   78,   79,   80,   81,   82,   83,   84,  103,
      103,  103,  103,   61,  103,  103,  103,    1,  103,  103,

      103,  103,  103,   39,  103,   74,  103,  103,  103,  103,
       95,   94,  103,  103,  103,  103,  103,  103,  103,  103,
       50,  103,   21,   26,  103,  103,  103,   10,  103,  103,
      103,  103,  103,   52,  103,  103,  103,  103,  103,   45,
       62,   95,   94,  103,    9,   67,  103,  103,  103,  103,
      103,  103,  103,  103,  103,  103,  103,  103,   47,  103,
      103,  103,  103,  103,   48,  103,   46,  103,   95,  103,
      103,  103,  103,  103,  103,  103,  103,  103,  103,   12,
      103,  103,  103,  103,  103,  103,   44,   11,  103,  103,
      103,  103,  103,  103,   95,  103,  103,  103,  103,  103,

       33,  103,  103,  103,  103,  103,  103,  103,  103,  103,
      103,  103,  103,    8,  103,  103,  103,  103,  103,  103,
      103,  103,  103,  103,  103,   43,   34,  103,  103,  103,
      103,  103,  103,  103,  103,  103,  103,  103,  103,  103,
      103,   20,  103,  103,  103,  103,   53,  103,  103,  103,
      103,  103,  103,  103,  103,  103,  103,  103,  103,  103,
       56,  103,  103,  103,  103,  103,   54,  103,  103,  103,
      103,  103,  103,  103,  103,  103,  103,  103,  103,  103,
       57,  103,  103,   15,  103,  103,  103,  103,   17,    7,
      103,  103,  103,  103,  103,  103,  103,   23,  103,  103,

      103,  103,  103,  103,  103,  103,  103,  103,  103,    4,
      103,  103,  103,   22,  103,  103,  103,  103,  103,   13,
      103,  103,  103,  103,    5,    6,  103,  103,  103,  103,
      103,  103,   16,  103,  103,  103,  103,  103,  103,    3,
       25,  103,   18,  103,  103,  103,   27,  103,   55,  103,
       24,   14,   58,  103,  103,  103,  103,   28,  103,  103,
      103,   29,    2,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    6,    7,    8,    9,    8,   10,
       11,    8,    8,    8,   12,    8,    8,   13,   14,   15,
       16,   17,   18,   19,   20,   21,   21,    8,    8,    8,
        8,    8,    8,    8,   22,   22,   22,   22,   22,   22,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        8,   23,    8,    8,   24,    8,   25,   26,   27,   28,

       29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
       39,   40,   41,   42,   43,   44,   45,   46,   47,   48,
       49,   50,    8,   51,    8,    8,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[52] =
    {   0,
        1,    2,    3,    1,    2,    1,    1,    1,    1,    1,
        1,    1,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1
    } ;

static yyconst flex_int16_t yy_base[571] =
    {   0,
        0,    0,  779,    0,   50,  780,    0,   49,   55,    0,
        0,    0,    0,   67,   59,  745,   19,   49,   34,   56,
      744,   29,   39,   59,  747,   30,   71,   70,  729,  749,
      728,   76,   74,  733,   65,  742,   82,    0,    0,  111,
      780,  767,   73,   97,  780,  134,  123,  766,  780,  170,
      179,  109,  116,  730,   93,  723,   94,    0,   88,  737,
      739,  721,   98,  734,  716,  731,  718,  730,    0,  719,
      728,  712,  719,    0,  716,  113,  711,  725,  709,  717,
      706,  701,  120,  711,  717,  119,  712,  706,  133,  118,
      698,  703,  701,  697,  699,  709,  710,  694,  693,  701,

      163,    0,  196,  214,  223,  140,  706,  690,  692,  698,
      693,  701,  683,  688,  688,  679,  696,  692,  692,  678,
      686,    0,  679,  690,  690,  675,  689,  673,  673,  675,
      671,  671,  683,    0,  671,  663,  662,  116,  671,  667,
      660,  668,  675,  655,  667,  669,  667,  650,  665,  648,
      646,  679,  646,  647,  648,  651,  650,  643,  644,  640,
      644,  637,    0,  232,  250,  259,  644,  635,  631,  637,
      643,  643,    0,    0,  635,  642,  633,    0,    0,  640,
      628,  627,  623,    0,    0,  640,    0,  624,  620,    0,
      635,  627,    0,  637,    0,  628,  175,  633,  647,  616,

      630,  619,    0,  626,    0,  627,  620,  608,  609,  617,
      620,  620,  605,  604,  606,  615,  631,    0,  609,  608,
      611,  276,  287,  296,  594,    0,  626,  595,  598,  623,
      596,    0,  595,    0,  593,  588,  586,    0,  600,  600,
      591,  305,  595,  582,  580,  583,  593,  591,  587,  590,
        0,  574,  575,    0,  583,  588,  576,  574,  583,  582,
      579,  563,  566,  568,  568,    0,  313,  322,  577,  574,
      570,  571,  560,    0,  562,  561,  586,  568,  584,  566,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  565,
      566,  580,  551,    0,  562,  561,  544,  575,  557,  541,

      555,  537,  535,    0,  538,    0,  551,  552,  540,  546,
      331,  340,  547,  547,  528,  561,  527,  542,  533,  128,
      557,  538,  555,    0,  527,  536,  522,    0,  534,  533,
      531,  548,  510,  546,  524,  518,  512,  518,  523,    0,
        0,  349,  540,  539,    0,    0,  251,  517,  522,  519,
      502,  507,  143,  517,  142,  506,  505,  513,    0,  499,
      512,  509,  252,  496,    0,  525,    0,  503,  358,  353,
      493,  491,  489,  488,  493,  487,  517,  483,  485,    0,
      493,  495,  485,  485,  476,  478,    0,    0,  492,  477,
      475,  478,  491,  479,    0,  478,  464,  469,  472,  481,

        0,  497,  464,  475,  255,  473,  466,  462,  474,  463,
      472,  467,  456,    0,  459,  468,  458,  453,  465,  460,
      449,  462,  445,  447,  456,    0,    0,  454,  158,  450,
      448,  455,  435,  447,  454,  438,  467,  433,  435,  439,
      444,    0,  445,  446,  430,  431,  458,  424,  432,  439,
      423,  421,  452,  436,  429,  416,  416,  420,  433,  417,
      444,  426,  411,  415,  413,  439,    0,  407,  409,  419,
      418,  410,  412,  353,  400,  400,  402,  429,  402,  397,
        0,  395,  399,    0,  392,  397,  392,  401,    0,    0,
      390,  392,  392,  396,  403,  388,  382,  413,  392,  386,

      391,  389,  376,  407,  388,  390,  387,  373,  374,    0,
      359,  356,  355,    0,  370,  349,  363,  348,  361,    0,
      362,  355,  357,  350,    0,    0,  356,  352,  334,  346,
      255,  256,    0,  257,  253,  260,  257,  253,  261,    0,
        0,  251,    0,  242,  248,  218,    0,  219,    0,  164,
        0,    0,    0,  176,  176,  164,  148,    0,  138,  148,
      128,    0,    0,  780,  398,  402,  406,  410,  167,  129
    } ;

static yyconst flex_int16_t yy_def[571] =
    {   0,
      564,    1,  564,  565,  564,  564,  565,  566,  567,  565,
      565,  565,  565,  565,  564,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  564,
      564,  568,  564,  566,  564,  566,  567,  568,  564,  565,
       14,  564,  564,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,

      564,  569,  566,  565,   14,  564,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  570,  103,  565,   14,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,

      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  566,  565,   14,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,   14,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,

      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,   14,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,

      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,

      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,    0,  564,  564,  564,  564,  564,  564
    } ;

static yyconst flex_int16_t yy_nxt[832] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,    4,   11,   12,
       13,    4,   14,   14,   14,   14,   14,   14,   14,   14,
       14,    4,   15,   16,   17,    4,   18,   19,   20,   21,
       22,   23,   24,    4,   25,   26,   27,   28,   29,   30,
       31,   32,   33,   34,   35,   36,   37,    4,    4,    4,
       38,   40,   41,   45,   55,   42,   48,   49,   60,   48,
       52,   53,   61,   56,   70,   72,   62,   73,   78,   79,
       71,   46,   43,   57,   52,   53,   58,   48,   50,   51,
       51,   51,   51,   51,   51,   51,   51,   51,   74,   75,
       59,   63,   64,   65,   66,   80,   76,   67,   82,   81,

       88,   45,   90,   68,   89,   91,   99,   96,   83,   97,
       52,   53,   40,   41,   84,   92,   42,  106,   93,   46,
      113,  108,   94,  100,   48,   49,  114,   48,  109,  111,
      118,  138,   44,   43,  564,  101,   44,  112,   43,  130,
      119,  106,  131,  196,  150,   48,  102,  102,  102,  102,
      102,  102,  102,  102,  102,  564,  142,  146,  197,  151,
      143,  152,   43,  139,  101,   44,  147,  351,  378,  381,
      163,  352,  379,  148,  382,  149,  563,  383,  562,  561,
      560,  103,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  105,  105,  105,  105,  105,  105,  105,  105,  105,

       45,  450,  559,  245,  558,  557,  451,  556,  164,  164,
      164,  164,  164,  164,  164,  164,  164,  164,   46,  246,
      164,  164,  164,  164,  164,  164,  165,  165,  165,  165,
      165,  165,  165,  165,  165,  166,  166,  166,  166,  166,
      166,  166,  166,  166,  222,  222,  222,  222,  222,  222,
      222,  222,  222,  222,  555,  554,  222,  222,  222,  222,
      222,  222,  223,  223,  223,  223,  223,  223,  223,  223,
      223,  224,  224,  224,  224,  224,  224,  224,  224,  224,
       45,  371,  390,  553,  428,  552,  551,  550,  549,  548,
      547,  546,  545,  544,  543,  372,  391,  429,   46,  267,

      267,  267,  267,  267,  267,  267,  267,  267,  268,  268,
      268,  268,  268,  268,  268,  268,  268,  282,  283,  284,
      285,  286,  287,  288,  289,  311,  311,  311,  311,  311,
      311,  311,  311,  311,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  342,  342,  342,  342,  342,  342,  342,
      342,  342,  343,  343,  343,  343,  343,  343,  343,  343,
      343,  369,  369,  369,  369,  369,  369,  369,  369,  369,
      395,  395,  395,  395,  395,  395,  395,  395,  395,  396,
      494,  542,  541,  540,  539,  538,  537,  536,  535,  534,
      533,  532,  495,  531,  530,  397,  529,  398,   39,  528,

      527,   39,   44,   44,  526,   44,   47,   47,   47,   47,
       48,   48,   48,   48,  525,  524,  523,  522,  521,  520,
      519,  518,  517,  516,  515,  514,  513,  512,  511,  510,
      509,  508,  507,  506,  505,  504,  503,  502,  501,  500,
      499,  498,  497,  496,  493,  492,  491,  490,  489,  488,
      487,  486,  485,  484,  483,  482,  481,  480,  479,  478,
      477,  476,  475,  474,  473,  472,  471,  470,  469,  468,
      467,  466,  465,  464,  463,  462,  461,  460,  459,  458,
      457,  456,  455,  454,  453,  452,  449,  448,  447,  446,
      445,  444,  443,  442,  441,  440,  439,  438,  437,  436,

      435,  434,  433,  432,  431,  430,  427,  426,  425,  424,
      423,  422,  421,  420,  419,  418,  417,  416,  415,  414,
      413,  412,  411,  410,  409,  408,  407,  406,  405,  404,
      403,  402,  401,  400,  399,  394,  393,  392,  389,  388,
      387,  386,  385,  384,  380,  377,  376,  375,  374,  373,
      370,   50,  368,  367,  366,  365,  364,  363,  346,  362,
      361,  360,  359,  358,  357,  356,  355,  354,  353,  350,
      349,  348,  347,  346,  345,  344,  341,  340,  339,  338,
      337,  336,  335,  334,  333,  332,  331,  330,  329,  328,
      327,  326,  325,  324,  323,  322,  321,  320,  319,  318,

      317,  316,  315,  314,  313,  310,  309,  308,  307,  306,
      305,  304,  303,  302,  301,  300,  299,  298,  297,  296,
      295,  294,  293,  292,  291,  290,  281,  280,  279,  278,
      277,  276,  275,  274,  273,  272,  271,  270,  269,  266,
      265,  264,  263,  262,  261,  260,  259,  258,  257,  256,
      255,  254,  253,  252,  251,  250,  234,  249,  248,  247,
      244,  243,  242,  241,  240,  239,  238,  237,  236,  235,
      234,  233,  232,  231,  230,  229,  228,  227,  226,  225,
      221,  220,  219,  218,  217,  216,  215,  214,  213,  212,
      211,  210,  209,  208,  207,  206,  205,  204,  203,  202,

      201,  200,  199,  198,  195,  194,  193,  192,  191,  190,
      189,  188,  187,  186,  185,  184,  183,  182,  181,  180,
      179,  178,  177,  176,  175,  174,  173,  172,  171,  170,
      169,  168,  167,  162,  161,  160,  159,  158,  157,  156,
      155,  154,  153,  145,  144,  141,  140,  137,  136,  135,
      134,  133,  132,  129,  128,  127,  126,  125,  124,  123,
      122,  121,  120,  117,  116,  115,  110,  107,   49,   49,
       98,   95,   87,   86,   85,   77,   69,   54,  564,    3,
      564,  564,  564,  564,  564,  564,  564,  564,  564,  564,
      564,  564,  564,  564,  564,  564,  564,  564,  564,  564,

      564,  564,  564,  564,  564,  564,  564,  564,  564,  564,
      564,  564,  564,  564,  564,  564,  564,  564,  564,  564,
      564,  564,  564,  564,  564,  564,  564,  564,  564,  564,
      564
    } ;

static yyconst flex_int16_t yy_chk[832] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    5,    8,   17,    5,    9,    9,   19,    9,
       15,   15,   19,   17,   22,   23,   19,   23,   26,   26,
       22,    8,    5,   18,   43,   43,   18,    9,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   24,   24,
       18,   20,   20,   20,   20,   27,   24,   20,   28,   27,

       32,   44,   33,   20,   32,   33,   37,   35,   28,   35,
       52,   52,   40,   40,   28,   33,   40,   53,   33,   44,
       59,   55,   33,   37,   47,   47,   59,   47,   55,   57,
       63,   83,  570,   40,   46,   46,   46,   57,   53,   76,
       63,  106,   76,  138,   90,   47,   46,   46,   46,   46,
       46,   46,   46,   46,   46,   46,   86,   89,  138,   90,
       86,   90,  106,   83,  101,  101,   89,  320,  353,  355,
      569,  320,  353,   89,  355,   89,  561,  355,  560,  559,
      557,   46,   50,   50,   50,   50,   50,   50,   50,   50,
       50,   51,   51,   51,   51,   51,   51,   51,   51,   51,

      103,  429,  556,  197,  555,  554,  429,  550,  103,  103,
      103,  103,  103,  103,  103,  103,  103,  103,  103,  197,
      103,  103,  103,  103,  103,  103,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  105,  105,  105,  105,  105,
      105,  105,  105,  105,  164,  164,  164,  164,  164,  164,
      164,  164,  164,  164,  548,  546,  164,  164,  164,  164,
      164,  164,  165,  165,  165,  165,  165,  165,  165,  165,
      165,  166,  166,  166,  166,  166,  166,  166,  166,  166,
      222,  347,  363,  545,  405,  544,  542,  539,  538,  537,
      536,  535,  534,  532,  531,  347,  363,  405,  222,  223,

      223,  223,  223,  223,  223,  223,  223,  223,  224,  224,
      224,  224,  224,  224,  224,  224,  224,  242,  242,  242,
      242,  242,  242,  242,  242,  267,  267,  267,  267,  267,
      267,  267,  267,  267,  268,  268,  268,  268,  268,  268,
      268,  268,  268,  311,  311,  311,  311,  311,  311,  311,
      311,  311,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  342,  342,  342,  342,  342,  342,  342,  342,  342,
      369,  369,  369,  369,  369,  369,  369,  369,  369,  370,
      474,  530,  529,  528,  527,  524,  523,  522,  521,  519,
      518,  517,  474,  516,  515,  370,  513,  370,  565,  512,

      511,  565,  566,  566,  509,  566,  567,  567,  567,  567,
      568,  568,  568,  568,  508,  507,  506,  505,  504,  503,
      502,  501,  500,  499,  498,  497,  496,  495,  494,  493,
      492,  491,  488,  487,  486,  485,  483,  482,  480,  479,
      478,  477,  476,  475,  473,  472,  471,  470,  469,  468,
      466,  465,  464,  463,  462,  461,  460,  459,  458,  457,
      456,  455,  454,  453,  452,  451,  450,  449,  448,  447,
      446,  445,  444,  443,  441,  440,  439,  438,  437,  436,
      435,  434,  433,  432,  431,  430,  428,  425,  424,  423,
      422,  421,  420,  419,  418,  417,  416,  415,  413,  412,

      411,  410,  409,  408,  407,  406,  404,  403,  402,  400,
      399,  398,  397,  396,  394,  393,  392,  391,  390,  389,
      386,  385,  384,  383,  382,  381,  379,  378,  377,  376,
      375,  374,  373,  372,  371,  368,  366,  364,  362,  361,
      360,  358,  357,  356,  354,  352,  351,  350,  349,  348,
      344,  343,  339,  338,  337,  336,  335,  334,  333,  332,
      331,  330,  329,  327,  326,  325,  323,  322,  321,  319,
      318,  317,  316,  315,  314,  313,  310,  309,  308,  307,
      305,  303,  302,  301,  300,  299,  298,  297,  296,  295,
      293,  292,  291,  290,  280,  279,  278,  277,  276,  275,

      273,  272,  271,  270,  269,  265,  264,  263,  262,  261,
      260,  259,  258,  257,  256,  255,  253,  252,  250,  249,
      248,  247,  246,  245,  244,  243,  241,  240,  239,  237,
      236,  235,  233,  231,  230,  229,  228,  227,  225,  221,
      220,  219,  217,  216,  215,  214,  213,  212,  211,  210,
      209,  208,  207,  206,  204,  202,  201,  200,  199,  198,
      196,  194,  192,  191,  189,  188,  186,  183,  182,  181,
      180,  177,  176,  175,  172,  171,  170,  169,  168,  167,
      162,  161,  160,  159,  158,  157,  156,  155,  154,  153,
      152,  151,  150,  149,  148,  147,  146,  145,  144,  143,

      142,  141,  140,  139,  137,  136,  135,  133,  132,  131,
      130,  129,  128,  127,  126,  125,  124,  123,  121,  120,
      119,  118,  117,  116,  115,  114,  113,  112,  111,  110,
      109,  108,  107,  100,   99,   98,   97,   96,   95,   94,
       93,   92,   91,   88,   87,   85,   84,   82,   81,   80,
       79,   78,   77,   75,   73,   72,   71,   70,   68,   67,
       66,   65,   64,   62,   61,   60,   56,   54,   48,   42,
       36,   34,   31,   30,   29,   25,   21,   16,    3,  564,
      564,  564,  564,  564,  564,  564,  564,  564,  564,  564,
      564,  564,  564,  564,  564,  564,  564,  564,  564,  564,

      564,  564,  564,  564,  564,  564,  564,  564,  564,  564,
      564,  564,  564,  564,  564,  564,  564,  564,  564,  564,
      564,  564,  564,  564,  564,  564,  564,  564,  564,  564,
      564
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "lexer.l"
/*
 *   Copyright (C)1996-1997,1999 Ian Jackson
 *  
 *   This is free software; you can redistribute it and/or modify it
 *   under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *  
 *   This program is distributed in the hope that it will be useful, but
 *   WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   General Public License for more details.
 *  
 *   You should have received a copy of the GNU General Public License
 *   along with userv; if not, write to the Free Software
 *   Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#line 20 "lexer.l"





#include <syslog.h>
#include <assert.h>
#include <stdio.h>
#include <stdarg.h>
#include <ctype.h>
#include <string.h>
#include <unistd.h>
#include <pwd.h>
#include <grp.h>
#include <fnmatch.h>
#include <limits.h>
#include <dirent.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <time.h>
#include <errno.h>

#include "config.h"
#include "common.h"
#include "daemon.h"
#include "lib.h"
#include "both.h"
#include "tokens.h"

#define HYPHEN '-'

typedef int directive_fnt(int dtoken);
static directive_fnt df_reject, df_execute, df_executefrompath;
static directive_fnt df_executefromdirectory, df_executebuiltin;
static directive_fnt df_errorstostderr, df_errorstosyslog, df_errorstofile;
static directive_fnt dfg_fdwant, dfg_setflag;
static directive_fnt df_reset, df_cd, df_userrcfile, df_include;
static directive_fnt df_includelookup, df_includedirectory;
static directive_fnt df_message, df_error, df_quit, df_eof;
static directive_fnt df_if, df_catchquit, df_errorspush;
static directive_fnt dfi_includeuserrcfile, dfi_includeclientconfig;
/* directive functions return:
 *  0 for success having scanned up to and including end of line but not beyond,
 *  or tokv_error or tokv_quit.
 * They expect to parse the whitespace before their parameters (if any).
 */

typedef int parmcondition_fnt(int ctoken, char *const *parmvalues, int *rtrue);
static parmcondition_fnt pcf_glob, pcf_range, pcf_grep;
/* all conditional functions return tokv_error for failure or 0 for success
 *  at parsing and testing, in which case *rtrue is set to 0 or 1.
 *  On success they have scanned up to and including the condition's
 *  terminating newline; the pcf_... functions expect to parse the whitespace
 *  between the parameter name and the condition's arguments.
 * Otherwise they return tokv_error.
 * The parameter-based conditionals take a list of parameter values
 * as obtained from the parameter functions and pa_parameter,
 * and do _not_ free it.
 */

typedef int parameter_fnt(int ptoken, char ***rvalues);
static parameter_fnt pf_service;
static parameter_fnt pf_callinguser, pf_serviceuser;
static parameter_fnt pf_callinggroup, pf_servicegroup;
static parameter_fnt pf_callingusershell, pf_serviceusershell;
/* Parameter functions return tokv_error or 0 for success at parsing
 * and determining the value, in which case *rvalues is made to be
 * a mallocd null-terminated array of pointers to mallocd strings.
 * freeparm can be used to free such an array.
 */

typedef int builtinserviceparse_fnt(char ***rnewargs);
static builtinserviceparse_fnt bispa_none, bispa_parameter;
/* These parse the arguments to a builtin service, including the
 * newline at the end of the line.  *rnewargs will initially be
 * null, indicating that no arguments are to be set; the function
 * may store a mallocd array of mallocd strings in it,
 * containing the arguments it wishes to have set (null-pointer
 * terminated).
 */

static int yylex(void);
/* Returns a token (which may be an eof or error exception) */

static directive_fnt *lr_dir;
static parmcondition_fnt *lr_parmcond;
static builtinserviceparse_fnt *lr_bispa;
static builtinserviceexec_fnt *lr_bisexec;
static parameter_fnt *lr_parameter;
static int lr_loglevel, lr_logfacility, lr_min, lr_max, *lr_flag;
static int lr_flagval, lr_controlend;
static int lr_fdwant_readwrite; /* -1=never, 0=opt, 1=always */

/* Forward declarations of things used in lexer and parser */

struct parser_state {
  int lineno, reportlineno, notedreferer, isinternal;
  const char *filename;
  struct stat filestab;
  YY_BUFFER_STATE ybuf;
  struct parser_state *upstate;
};

static struct parser_state *cstate;

struct error_handling {
  int handling; /* One of the error handling modes tokt_ehandlemode */
  int logfacility, loglevel;
  int filekeep; /* File is in use by higher-level errors-push, leave it open */
  FILE *file;
  char *filename;
};

static struct error_handling eh = { tokv_word_errorstostderr, 0,0,0,0,0 };

static int dequote(char *inplace);
static void countnewlines(void);

#define YY_NO_UNPUT

#line 952 "<stdout>"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 144 "lexer.l"


#line 1106 "<stdout>"

	if ( (yy_init) )
		{
		(yy_init) = 0;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 565 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 780 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 146 "lexer.l"
{ lr_dir= df_reject; return tokv_word_reject; }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 147 "lexer.l"
{ lr_dir= df_executefromdirectory; return tokv_word_executefromdirectory; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 148 "lexer.l"
{ lr_dir= df_executefrompath; return tokv_word_executefrompath; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 149 "lexer.l"
{ lr_dir= df_executebuiltin; return tokv_word_executebuiltin; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 150 "lexer.l"
{ lr_dir= df_errorstostderr; return tokv_word_errorstostderr; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 151 "lexer.l"
{ lr_dir= df_errorstosyslog; return tokv_word_errorstosyslog; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 152 "lexer.l"
{ lr_dir= df_errorstofile; return tokv_word_errorstofile; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 153 "lexer.l"
{ lr_dir= dfg_fdwant; lr_fdwant_readwrite=1; return tokv_word_requirefd; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 154 "lexer.l"
{ lr_dir= dfg_fdwant; lr_fdwant_readwrite=0; return tokv_word_allowfd; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 155 "lexer.l"
{ lr_dir= dfg_fdwant; lr_fdwant_readwrite=0; return tokv_word_nullfd; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 156 "lexer.l"
{ lr_dir= dfg_fdwant; lr_fdwant_readwrite=-1; return tokv_word_rejectfd; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 157 "lexer.l"
{ lr_dir= dfg_fdwant; lr_fdwant_readwrite=-1; return tokv_word_ignorefd; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 158 "lexer.l"
{ lr_dir= dfg_setflag; lr_flag= &setenvironment; lr_flagval= 1; return tokv_word_setenvironment; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 159 "lexer.l"
{ lr_dir= dfg_setflag; lr_flag= &setenvironment; lr_flagval= 0; return tokv_word_nosetenvironment; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 160 "lexer.l"
{ lr_dir= dfg_setflag; lr_flag= &suppressargs; lr_flagval= 1; return tokv_word_suppressargs; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 161 "lexer.l"
{ lr_dir= dfg_setflag; lr_flag= &suppressargs; lr_flagval= 0; return tokv_word_nosuppressargs; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 162 "lexer.l"
{ lr_dir= dfg_setflag; lr_flag= &disconnecthup; lr_flagval= 1; return tokv_word_disconnecthup; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 163 "lexer.l"
{ lr_dir= dfg_setflag; lr_flag= &disconnecthup; lr_flagval= 0; return tokv_word_nodisconnecthup; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 164 "lexer.l"
{ lr_dir= df_cd; return tokv_word_cd; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 165 "lexer.l"
{ lr_dir= df_userrcfile; return tokv_word_userrcfile; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 166 "lexer.l"
{ lr_dir= df_include; return tokv_word_include; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 167 "lexer.l"
{ lr_dir= df_include; return tokv_word_includeifexist; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 168 "lexer.l"
{ lr_dir= df_includelookup; return tokv_word_includelookup; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 169 "lexer.l"
{ lr_dir= df_includelookup; return tokv_word_includelookupall; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 170 "lexer.l"
{ lr_dir= df_includedirectory; return tokv_word_includedirectory; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 171 "lexer.l"
{ lr_dir= df_message; return tokv_word_message; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 172 "lexer.l"
{ lr_dir= df_include; return tokv_word_includesysconfig; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 173 "lexer.l"
{ lr_dir= dfi_includeuserrcfile; return tokv_word_includeuserrcfile; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 174 "lexer.l"
{ lr_dir= dfi_includeclientconfig; return tokv_word_includeclientconfig; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 175 "lexer.l"
{ lr_dir= df_quit; return tokv_word_quit; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 176 "lexer.l"
{ lr_dir= df_eof; return tokv_word_eof; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 177 "lexer.l"
{ lr_dir= df_if; return tokv_word_if; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 178 "lexer.l"
{ lr_dir= df_catchquit; return tokv_word_catchquit; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 179 "lexer.l"
{ lr_dir= df_errorspush; return tokv_word_errorspush; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 180 "lexer.l"
{ lr_controlend= tokv_word_if; return tokv_word_elif; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 181 "lexer.l"
{ lr_controlend= tokv_word_if; return tokv_word_else; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 182 "lexer.l"
{ lr_controlend= tokv_word_if; return tokv_word_fi; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 183 "lexer.l"
{ lr_controlend= tokv_word_catchquit; return tokv_word_hctac; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 184 "lexer.l"
{ lr_controlend= tokv_word_errorspush; return tokv_word_srorre; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 185 "lexer.l"
{ lr_parmcond= pcf_glob; return tokv_word_glob; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 186 "lexer.l"
{ lr_parmcond= pcf_range; return tokv_word_range; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 187 "lexer.l"
{ lr_parmcond= pcf_grep; return tokv_word_grep; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 188 "lexer.l"
{ lr_bispa= bispa_none; lr_bisexec= bisexec_environment; return tokv_word_environment; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 189 "lexer.l"
{ lr_bispa= bispa_parameter; lr_bisexec= bisexec_parameter; return tokv_word_parameter; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 190 "lexer.l"
{ lr_bispa= bispa_none; lr_bisexec= bisexec_version; return tokv_word_version; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 191 "lexer.l"
{ lr_bispa= bispa_none; lr_bisexec= bisexec_toplevel; return tokv_word_toplevel; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 192 "lexer.l"
{ lr_bispa= bispa_none; lr_bisexec= bisexec_override; return tokv_word_override; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 193 "lexer.l"
{ lr_bispa= bispa_none; lr_bisexec= bisexec_shutdown; return tokv_word_shutdown; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 194 "lexer.l"
{ lr_bispa= bispa_none; lr_bisexec= bisexec_reset; lr_dir= df_reset; return tokv_word_reset; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 195 "lexer.l"
{ lr_bispa= bispa_none; lr_bisexec= bisexec_execute; lr_dir= df_execute; return tokv_word_execute; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 196 "lexer.l"
{ lr_bispa= bispa_none; lr_bisexec= bisexec_help; return tokv_word_help; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 197 "lexer.l"
{ lr_parameter= pf_service; return tokv_word_service; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 198 "lexer.l"
{ lr_parameter= pf_callinguser; return tokv_word_callinguser; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 199 "lexer.l"
{ lr_parameter= pf_callinggroup; return tokv_word_callinggroup; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 200 "lexer.l"
{ lr_parameter= pf_callingusershell; return tokv_word_callingusershell; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 201 "lexer.l"
{ lr_parameter= pf_serviceuser; return tokv_word_serviceuser; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 202 "lexer.l"
{ lr_parameter= pf_servicegroup; return tokv_word_servicegroup; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 203 "lexer.l"
{ lr_parameter= pf_serviceusershell; return tokv_word_serviceusershell; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 204 "lexer.l"
{ lr_loglevel= LOG_DEBUG; return tokv_syslog_debug; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 205 "lexer.l"
{ lr_loglevel= LOG_INFO; return tokv_syslog_info; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 206 "lexer.l"
{ lr_loglevel= LOG_NOTICE; return tokv_syslog_notice; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 207 "lexer.l"
{ lr_loglevel= LOG_WARNING; return tokv_syslog_warning; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 208 "lexer.l"
{ lr_loglevel= LOG_ERR; return tokv_syslog_err; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 209 "lexer.l"
{ lr_loglevel= LOG_CRIT; return tokv_syslog_crit; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 210 "lexer.l"
{ lr_loglevel= LOG_ALERT; return tokv_syslog_alert; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 211 "lexer.l"
{ lr_loglevel= LOG_EMERG; return tokv_syslog_emerg; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 212 "lexer.l"
{ lr_logfacility= LOG_AUTHPRIV; return tokv_syslog_authpriv; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 213 "lexer.l"
{ lr_logfacility= LOG_CRON; return tokv_syslog_cron; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 214 "lexer.l"
{ lr_logfacility= LOG_DAEMON; return tokv_syslog_daemon; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 215 "lexer.l"
{ lr_logfacility= LOG_KERN; return tokv_syslog_kern; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 216 "lexer.l"
{ lr_logfacility= LOG_LPR; return tokv_syslog_lpr; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 217 "lexer.l"
{ lr_logfacility= LOG_MAIL; return tokv_syslog_mail; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 218 "lexer.l"
{ lr_logfacility= LOG_NEWS; return tokv_syslog_news; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 219 "lexer.l"
{ lr_logfacility= LOG_SYSLOG; return tokv_syslog_syslog; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 220 "lexer.l"
{ lr_logfacility= LOG_USER; return tokv_syslog_user; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 221 "lexer.l"
{ lr_logfacility= LOG_UUCP; return tokv_syslog_uucp; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 222 "lexer.l"
{ lr_logfacility= LOG_LOCAL0; return tokv_syslog_local0; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 223 "lexer.l"
{ lr_logfacility= LOG_LOCAL1; return tokv_syslog_local1; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 224 "lexer.l"
{ lr_logfacility= LOG_LOCAL2; return tokv_syslog_local2; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 225 "lexer.l"
{ lr_logfacility= LOG_LOCAL3; return tokv_syslog_local3; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 226 "lexer.l"
{ lr_logfacility= LOG_LOCAL4; return tokv_syslog_local4; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 227 "lexer.l"
{ lr_logfacility= LOG_LOCAL5; return tokv_syslog_local5; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 228 "lexer.l"
{ lr_logfacility= LOG_LOCAL6; return tokv_syslog_local6; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 229 "lexer.l"
{ lr_logfacility= LOG_LOCAL7; return tokv_syslog_local7; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 230 "lexer.l"
{ return tokv_word_read; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 231 "lexer.l"
{ return tokv_word_write; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 232 "lexer.l"
{ return tokv_dollar; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 233 "lexer.l"
{ return tokv_openparen; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 234 "lexer.l"
{ return tokv_closeparen; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 235 "lexer.l"
{ return tokv_not; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 236 "lexer.l"
{ return tokv_and; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 237 "lexer.l"
{ return tokv_or; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 238 "lexer.l"
{ lr_dir= df_error; lr_loglevel= LOG_ERR; return tokv_word_error; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 242 "lexer.l"
{
			  char *ep;
			  lr_min=lr_max= (int)strtoul(yytext,&ep,10);
			  assert(!*ep);
			  return tokv_ordinal;
			}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 248 "lexer.l"
{
			  char *ep;
			  lr_min= (int)strtoul(yytext,&ep,10);
			  assert(*ep == HYPHEN);
			  ep++;  assert(*ep);
			  lr_max= (int)strtoul(ep,&ep,10);
			  assert(!*ep);
			  if (lr_max < lr_min)
			    return parseerrprint("fd range has min > max");
			  return tokv_fdrange;
			}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 259 "lexer.l"
{
			  char *ep;
			  lr_min= (int)strtoul(yytext,&ep,10);
			  assert(*ep == HYPHEN);
			  ep++;  assert(!*ep);
			  lr_max=-1;
			  return tokv_fdstoend;
			}
	YY_BREAK
case 97:
/* rule 97 can match eol */
YY_RULE_SETUP
#line 267 "lexer.l"
countnewlines(); return tokv_lwsp;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 268 "lexer.l"
return tokv_lwsp;
	YY_BREAK
case 99:
/* rule 99 can match eol */
YY_RULE_SETUP
#line 269 "lexer.l"
cstate->lineno++; return tokv_newline;
	YY_BREAK
case 100:
/* rule 100 can match eol */
YY_RULE_SETUP
#line 270 "lexer.l"
cstate->lineno++; return tokv_newline;
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 271 "lexer.l"
return parseerrprint("missing newline at eof after comment");
	YY_BREAK
case 102:
/* rule 102 can match eol */
YY_RULE_SETUP
#line 272 "lexer.l"
{
			  countnewlines();
			  return dequote(yytext);
			}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 276 "lexer.l"
return tokv_barestring;
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 277 "lexer.l"
return tokv_eof;
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 278 "lexer.l"
return parseerrprint("misquoted or unterminated string");
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 279 "lexer.l"
return parseerrprint("unexpected backslash");
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 280 "lexer.l"
abort(); /* expect lex warning "rule cannot be matched" */
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 283 "lexer.l"
ECHO;
	YY_BREAK
#line 1757 "<stdout>"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 565 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 565 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 564);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param str a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yy_str )
{
    
	return yy_scan_bytes(yy_str,strlen(yy_str) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * bytes, int  len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < len; ++i )
		buf[i] = bytes[i];

	buf[len] = buf[len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
    	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
    	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#undef YY_NEW_FILE
#undef YY_FLUSH_BUFFER
#undef yy_set_bol
#undef yy_new_buffer
#undef yy_set_interactive
#undef yytext_ptr
#undef YY_DO_BEFORE_ACTION

#ifdef YY_DECL_IS_OURS
#undef YY_DECL_IS_OURS
#undef YY_DECL
#endif
#line 283 "lexer.l"



const char *const builtinservicehelpstrings[]= {
  "environment",
  "parameter <parameter>",
  "version",
  "toplevel",
  "override",
  "shutdown",
  "reset",
  "execute",
  "help",
   0
};

#include "parser.c"


